package com.supervision.knowsub.controller.knowledge;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.knowsub.entity.vo.knowledge.KnowledgeFlowRecordResVO;
import com.supervision.knowsub.entity.vo.knowledge.ProcessFlowReqVO;
import com.supervision.knowsub.model.KnowledgeFlowRecord;
import com.supervision.knowsub.service.KnowledgeFlowService;
import com.supervision.knowsub.vo.knowledge.KnowledgeFlowResVO;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.enums.ParameterIn;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.servlet.mvc.condition.RequestConditionHolder;

import java.time.Instant;
import java.time.LocalDateTime;
import java.util.List;

@Slf4j
@RestController
@Tag(name = "知识流程")
@RequiredArgsConstructor
@RequestMapping("knowledgeFlow")
public class KnowledgeFlowController {

    private final KnowledgeFlowService knowledgeFlowService;

    @Operation(summary = "分页查询知识审批流程")
    @Parameters({
            @Parameter(name = "processStatus", description = "审批状态 1未审批 2已审批", in = ParameterIn.QUERY),
            @Parameter(name = "title", description = "标题,支持模糊", in = ParameterIn.QUERY),
            @Parameter(name = "publishDeptId", description = "发文部门id", in = ParameterIn.QUERY),
            @Parameter(name = "baseId", description = "应用字库ID", in = ParameterIn.QUERY),
            @Parameter(name = "submittedDeptId", description = "报送部门ID", in = ParameterIn.QUERY),
            @Parameter(name = "flowType", description = "审批类型 1知识报送 2:知识撤回 3 知识删除", in = ParameterIn.QUERY),
            @Parameter(name = "publishDateBegin", description = "发文时间开始", in = ParameterIn.QUERY),
            @Parameter(name = "publishDateEnd", description = "发文时间结束", in = ParameterIn.QUERY),
            @Parameter(name = "pageNum", description = "分页", in = ParameterIn.QUERY),
            @Parameter(name = "pageSize", description = "分页", in = ParameterIn.QUERY)
    })
    @GetMapping("queryKnowledgeFlowPage")
    public IPage<KnowledgeFlowResVO> queryKnowledgeFlowPage(Integer processStatus,
                                                            @RequestParam(required = false) String title,
                                                            @RequestParam(required = false) String publishDeptId,
                                                            @RequestParam(required = false) String baseId,
                                                            @RequestParam(required = false) String submittedDeptId,
                                                            @RequestParam(required = false) Instant flowType,
                                                            @RequestParam(required = false) LocalDateTime publishDateBegin,
                                                            @RequestParam(required = false) LocalDateTime publishDateEnd,
                                                            Integer pageNum, Integer pageSize) {
        return knowledgeFlowService.queryKnowledgeFlowPage(processStatus, title, publishDeptId, baseId, submittedDeptId, flowType,
                publishDateBegin, publishDateEnd, pageNum, pageSize);
    }

    @Operation(summary = "审批知识流程")
    @PostMapping("processKnowledgeFlow")
    public void processKnowledgeFlow(@RequestBody ProcessFlowReqVO reqVO) {
        knowledgeFlowService.processKnowledgeFlow(reqVO);
    }

    @Operation(summary = "查询知识库流转记录")
    @Parameters({
            @Parameter(name = "knowledgeId", description = "审批状态 1未审批 2已审批", in = ParameterIn.QUERY),
            @Parameter(name = "flowId", description = "标题,支持模糊", in = ParameterIn.QUERY)
    })
    @GetMapping("queryKnowledgeFlowRecord")
    public List<KnowledgeFlowRecordResVO> queryKnowledgeFlowRecord(String knowledgeId, @RequestParam(required = false) String flowId) {
        return knowledgeFlowService.queryKnowledgeFlowRecord(knowledgeId, flowId);
    }


}
