package com.supervision.knowsub.controller.system;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.knowsub.service.ApplicationSubLibraryService;
import com.supervision.knowsub.service.FlowManageService;
import com.supervision.knowsub.vo.flow.BaseResVo;
import com.supervision.knowsub.vo.flow.FlowInfoReqVo;
import com.supervision.knowsub.vo.flow.FlowInfoResVo;
import com.supervision.knowsub.vo.sublibrary.SubLibraryReqVo;
import com.supervision.knowsub.vo.sublibrary.SubLibraryResVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "流程管理")
@RestController
@RequestMapping("/flow")
@RequiredArgsConstructor
public class FlowManageController {


    private final FlowManageService flowManageService;

    @Operation(summary = "新建流程")
    @PostMapping("/save")
    public String saveFlow(@RequestBody FlowInfoReqVo flowInfoReqVo) {

        return flowManageService.saveFlow(flowInfoReqVo);
    }

    @Operation(summary = "修改流程")
    @PostMapping("/update")
    public void updateFlow(@RequestBody FlowInfoReqVo flowInfoReqVo) {

        flowManageService.updateFlow(flowInfoReqVo);
    }

    @Operation(summary = "删除流程")
    @DeleteMapping("/delete")
    public Boolean deleteFlow(@Parameter(name = "id") @RequestParam(name="id") String id) {

        return flowManageService.deleteFlow(id);
    }

    @Operation(summary = "分页查询流程列表")
    @GetMapping("/list")
    public IPage<FlowInfoResVo> listFlow(@Parameter(name = "flowName",description = "流程名称") @RequestParam(required = false) String flowName,
                                         @Parameter(name = "pageNum",description = "页码") @RequestParam(defaultValue = "1") Integer pageNum,
                                         @Parameter(name = "pageSize",description = "每页大小") @RequestParam(defaultValue = "10") Integer pageSize) {

        return flowManageService.pageListFlow(flowName,pageNum,pageSize);
    }

    @Operation(summary = "查询可选择的子库信息列表")
    @GetMapping("/optionalBaseList")
    public List<BaseResVo> optionalBaseList(@Parameter(name = "flowType",description = "数据类型id，多个id用英文逗号拼接")
                                                @RequestParam(name = "flowType",required = false) List<Integer> flowType) {

        return flowManageService.optionalBaseList(flowType);
    }
}
