package com.supervision.knowsub.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.io.unit.DataSizeUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.annotation.TableField;
import com.supervision.knowsub.model.FileBlob;
import com.supervision.knowsub.model.FileInfo;
import com.supervision.knowsub.service.FileBlobService;
import com.supervision.knowsub.service.FileInfoService;
import com.supervision.knowsub.service.FileService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

@Service
@Slf4j
@RequiredArgsConstructor
public class FileServiceImpl implements FileService {


    private final FileInfoService fileInfoService;

    private final FileBlobService fileBlobService;


    @Override
    @Transactional(rollbackFor = Exception.class)
    public String uploadFile(String fileName, byte[] fileBytes) {
        log.info("{}:文件进行保存", fileName);
        FileBlob fileBlob = new FileBlob();
        fileBlob.setBlobByte(fileBytes);
        fileBlob.insert();

        FileInfo fileInfo = new FileInfo();
        fileInfo.setFileName(fileName);
        fileInfo.setFileSize(fileBytes.length);
        fileInfo.setFileSizeStr(DataSizeUtil.format(fileBytes.length));
        fileInfo.setFileType(FileUtil.getSuffix(fileName));
        fileInfo.setFileBlobId(fileBlob.getId());
        fileInfoService.save(fileInfo);
        log.info("{}:文件保存成功", fileName);
        return fileInfo.getId();

    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteFileById(String fileId) {
        FileInfo one = fileInfoService.lambdaQuery().eq(FileInfo::getId, fileId).one();
        if (ObjectUtil.isNotEmpty(one)){
            fileBlobService.removeById(one.getFileBlobId());
            fileInfoService.removeById(fileId);
        }
    }

    @Override
    public List<FileInfo> listByFileId(List<String> fileIdList) {
        if (CollUtil.isEmpty(fileIdList)){
            return new ArrayList<>();
        }
        return fileInfoService.lambdaQuery().in(FileInfo::getId, fileIdList).list();
    }
}
